==> libpdsdatafunc-0.06.0.tar.gz: libpdsdatafunc-0.06.0/src/testprog2.c <==
/*
 * testprog2.c
 * 
 * Copyright 2011 Fernando Pujaico Rivera <fernando.pujaico.rivera@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 */


/** \example testprog2.c
 *  \author Fernando Pujaico Rivera
 *  \date 18-04-2016
 *  \brief Programa para el testeo de algunas funciones de la biblioteca.
 *  
 *  Este programa solo hace una prueba simple de las funciones que hice
 *  mas al tun tun.
 */


// ./testprog2 /mnt/boveda/Vídeos/BAILE/SALSA testprog2.dat
#include <config.h>
#include <stdlib.h>
#include <pds/pdsdatafunc.h>

int main(int argc, char* argv[])
{
    PdsCellString *L=NULL;
    PdsCellString *Lfall=NULL;
    PdsCellString *Lall=NULL;
    char testfile[]="biblioteca";
    char ltestfile[]="link-testprog2.dat";
    
    char cadena[]="/path_to_file/filename.c";

    ////////////////////////////////////////////////////////////////////////////

    Lall=pds_get_all_subdirs_new(argv[1],"*",".*");
    if(Lall==NULL) return EXIT_FAILURE;
    
    printf("\n<<<< List DIR >>>>\n");
    pds_cell_string_all_printf(Lall);


    ////////////////////////////////////////////////////////////////////////////

    Lfall=pds_get_all_files_new(argv[1],"*",".*","*",NULL);
    if(Lfall==NULL) return EXIT_FAILURE;
    
    printf("\n<<<< List FILE>>>>\n");
    pds_cell_string_all_printf(Lfall);

    ////////////////////////////////////////////////////////////////////////////

    printf("\n<<<< Names >>>>\n");
    printf("filepath :\t%s\n",cadena);
    printf("basename :\t%s\n",pds_get_basename(cadena));
    printf("extension:\t%s\n",pds_get_filename_extension(cadena));
    printf("filename :\t%s\n",pds_get_filename(cadena));
    printf("dirname  :\t%s\n",pds_get_dirname(cadena));


    ////////////////////////////////////////////////////////////////////////////
    printf("\n<<<< About files >>>>\n");
    if(pds_is_file(ltestfile)==FALSE)
                                              printf("%20s is not a file\n",ltestfile);
    else                                      printf("%20s is a file\n",ltestfile);

    if(pds_is_file(testfile)==FALSE)
                                              printf("%20s is not a file\n",testfile);
    else                                      printf("%20s is a file\n",testfile);

    if(pds_is_dir(ltestfile)==FALSE)
                                              printf("%20s is not a dir\n",ltestfile);
    else                                      printf("%20s is a dir\n",ltestfile);

    if(pds_is_dir(testfile)==FALSE)
                                              printf("%20s is not a dir\n",testfile);
    else                                      printf("%20s is a dir\n",testfile);

    if(pds_exist_file(ltestfile)==FALSE)
                                              printf("%20s not exist the file\n",ltestfile);
    else                                      printf("%20s exist\n",ltestfile);

    if(pds_exist_file(testfile)==FALSE)  
                                              printf("%20s not exist the file\n",testfile);
    else                                      printf("%20s exist\n",testfile);

    if(pds_archive_is_accessible(ltestfile)==FALSE)  
                                              printf("%20s not is accessible\n",ltestfile);
    else                                      printf("%20s is accessible\n",ltestfile);

    if(pds_archive_is_accessible(testfile)==FALSE)
                                              printf("%20s not is accessible\n",testfile);
    else                                      printf("%20s is accessible\n",testfile);

    ////////////////////////////////////////////////////////////////////////////
    if(argc<3)  return EXIT_FAILURE;
    L=pds_cell_string_new_load_data(argv[2]);
    if(L==NULL) return EXIT_FAILURE;

    printf("\n<<<< List >>>>\n");
    pds_cell_string_all_printf(L);


    return EXIT_SUCCESS;
}

==> libpdsdatafunc-0.07.0.tar.gz: libpdsdatafunc-0.07.0/src/testprog2.c <==
/*
 * testprog2.c
 * 
 * Copyright 2011 Fernando Pujaico Rivera <fernando.pujaico.rivera@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 */


/** \example testprog2.c
 *  \author Fernando Pujaico Rivera
 *  \date 18-04-2016
 *  \brief Programa para el testeo de algunas funciones de la biblioteca.
 *  
 *  Este programa solo hace una prueba simple de las funciones que hice
 *  mas al tun tun.
 */


// ./testprog2 /mnt/boveda/Vídeos/BAILE/SALSA testprog2.dat
#include <config.h>
#include <stdlib.h>
#include <pds/pdsdatafunc.h>

int main(int argc, char* argv[])
{
    PdsCellString *L=NULL;
    PdsCellString *Lfall=NULL;
    PdsCellString *Lall=NULL;
    char testfile[]="biblioteca";
    char ltestfile[]="testprog2.c";
    
    char cadena[]="/path_to_file/filename.c";

    ////////////////////////////////////////////////////////////////////////////

    Lall=pds_get_all_subdirs_new(argv[1],"*",".*");
    if(Lall==NULL) return EXIT_FAILURE;
    
    printf("\n<<<< List DIR >>>>\n");
    pds_cell_string_all_printf(Lall);


    ////////////////////////////////////////////////////////////////////////////

    Lfall=pds_get_all_files_new(argv[1],"*",".*","*",NULL);
    if(Lfall==NULL) return EXIT_FAILURE;
    
    printf("\n<<<< List FILE>>>>\n");
    pds_cell_string_all_printf(Lfall);

    ////////////////////////////////////////////////////////////////////////////

    printf("\n<<<< Names >>>>\n");
    printf("filepath :\t%s\n",cadena);
    printf("basename :\t%s\n",pds_get_basename(cadena));
    printf("extension:\t%s\n",pds_get_filename_extension(cadena));
    printf("filename :\t%s\n",pds_get_filename(cadena));
    printf("dirname  :\t%s\n",pds_get_dirname(cadena));


    ////////////////////////////////////////////////////////////////////////////
    printf("\n<<<< About files >>>>\n");
    if(pds_is_file(ltestfile)==FALSE)
                                              printf("%20s is not a file\n",ltestfile);
    else                                      printf("%20s is a file\n",ltestfile);

    if(pds_is_file(testfile)==FALSE)
                                              printf("%20s is not a file\n",testfile);
    else                                      printf("%20s is a file\n",testfile);

    if(pds_is_dir(ltestfile)==FALSE)
                                              printf("%20s is not a dir\n",ltestfile);
    else                                      printf("%20s is a dir\n",ltestfile);

    if(pds_is_dir(testfile)==FALSE)
                                              printf("%20s is not a dir\n",testfile);
    else                                      printf("%20s is a dir\n",testfile);

    if(pds_exist_file(ltestfile)==FALSE)
                                              printf("%20s not exist the file\n",ltestfile);
    else                                      printf("%20s exist\n",ltestfile);

    if(pds_exist_file(testfile)==FALSE)  
                                              printf("%20s not exist the file\n",testfile);
    else                                      printf("%20s exist\n",testfile);

    if(pds_archive_is_accessible(ltestfile)==FALSE)  
                                              printf("%20s not is accessible\n",ltestfile);
    else                                      printf("%20s is accessible\n",ltestfile);

    if(pds_archive_is_accessible(testfile)==FALSE)
                                              printf("%20s not is accessible\n",testfile);
    else                                      printf("%20s is accessible\n",testfile);

    ////////////////////////////////////////////////////////////////////////////
    if(argc<3)  return EXIT_FAILURE;
    L=pds_cell_string_new_load_data(argv[2]);
    if(L==NULL) return EXIT_FAILURE;

    printf("\n<<<< List >>>>\n");
    pds_cell_string_all_printf(L);


    return EXIT_SUCCESS;
}
